diff --git a/views/blog-rss.handlebars b/views/blog-rss.handlebars
index e23fe34..5522bca 100644
--- a/views/blog-rss.handlebars
+++ b/views/blog-rss.handlebars
@@ -22,6 +22,7 @@
https://pretendo.network/blog/{{this.slug}}
https://pretendo.network/blog/{{this.slug}}
{{ this.postInfo.pubDate }}
+
{{/each}}
diff --git a/src/routers/blog.js b/src/routers/blog.js
index 2e85cc4..2d72efc 100644
--- a/src/routers/blog.js
+++ b/src/routers/blog.js
@@ -49,9 +49,10 @@ router.get('/', async (request, response) => {
// RSS feed
router.get('/feed.xml', async (request, response) => {
// Adds the pubDate to the post array
const posts = postList().map((post) => {
post.postInfo.pubDate = new Date(post.postInfo.date).toUTCString();
+ post.postInfo.cover_extension = post.postInfo.cover_image.substring(post.postInfo.cover_image.lastIndexOf('.') + 1);
return post;
});
@@ -49,9 +49,10 @@ router.get('/', async (request, response) => {
// RSS feed
router.get('/feed.xml', async (request, response) => {
- // Adds the pubDate to the post array
+ // Adds the pubDate and the cover_extension to the post array
const posts = postList().map((post) => {
post.postInfo.pubDate = new Date(post.postInfo.date).toUTCString();